@@ -191,7 +191,7 @@ class EventManager:
         offsetEnd=None,
         fixedDuration=None,
         addClosingTags=False,
-        defaultValue=""
+        defaultValue="",
     ):
 
         newGroupName = groupToAppend if newGroupName is None else newGroupName
@@ -254,7 +254,7 @@ class EventManager:
 
     def getEventSignalFromEventDF(self, eventDF, targetFrequency=0, eventName="name"):
         return self.getWdfbCompatibleEventsFromList(eventDF.iloc, targetFrequency, eventName=eventName)
-    
+
     def getWdfbCompatibleEventsFromList(self, events: List[Event], targetFrequency=0, eventName="name"):
         # transform the evnent list to wfdb compatible annotatio: [5, (event1], [6, event1)] or [[30, W], [60, R]]
         wdfbEvents = []
@@ -276,8 +276,12 @@ class EventManager:
                 wdfbEvents.append([start, name])
 
         return wdfbEvents
-    
-    def getWdfbCompatibleEventsFromEventList(self, events: List[Event], targetFrequency=0,):
+
+    def getWdfbCompatibleEventsFromEventList(
+        self,
+        events: List[Event],
+        targetFrequency=0,
+    ):
         # transform the evnent list to wfdb compatible annotatio: [5, (event1], [6, event1)] or [[30, W], [60, R]]
         wdfbEvents = []
         for e in events:
@@ -302,7 +306,7 @@ class EventManager:
     def getEventSignalFromDF(self, events: List[Event], shape, targetFrequency, forceGapBetweenEvents=False, eventName="name"):
         wfdbEvents = self.getEventSignalFromEventDF(events, targetFrequency, eventName=eventName)
         return self.getEventSignalFromAnnotationMap(wfdbEvents, shape, forceGapBetweenEvents=forceGapBetweenEvents)
-    
+
     def getEventSignalFromList(self, events: List[Event], shape, targetFrequency, forceGapBetweenEvents=False):
         wfdbEvents = self.getWdfbCompatibleEventsFromEventList(events, targetFrequency)
         return self.getEventSignalFromAnnotationMap(wfdbEvents, shape, forceGapBetweenEvents=forceGapBetweenEvents)
@@ -411,7 +415,7 @@ class EventManager:
                     raise EventWrongOrdering(eventName, eventValue)
 
                 if (eventName == defaultEventName) & ((eventEnd - eventStart) % defaultEventEpochLength > 0):
-                    self.logWarning("%s epoch not with length %s"%(defaultEventName,defaultEventEpochLength))
+                    self.logWarning("%s epoch not with length %s" % (defaultEventName, defaultEventEpochLength))
 
                 if any(eventSignals[eventName][slice(eventStart, eventEnd)] == eventValue) & (eventValue != emptySignalValue):
                     self.logWarning("the event %s:%i is overlapping itself " % (eventName, eventValue))
