@@ -29,7 +29,9 @@ class Preprocessing:
         instance.targetChannels = preprocessingConfig["targetChannels"]
         instance.stepsByType = preprocessingConfig["stepsPerType"]
         instance.forceGapBetweenEvents = preprocessingConfig["forceGapBetweenEvents"]
-        instance.extendEvents = preprocessingConfig["extendEvents"] if "extendEvents" in preprocessingConfig else None
+        instance.eventConfig = {
+            "extendEvents": preprocessingConfig["extendEvents"] if "extendEvents" in preprocessingConfig else None
+        }
 
         cls.instance = instance
 
@@ -692,16 +694,17 @@ class Preprocessing:
                     raise ChannelsNotPresent(cName, signal.recordId)
 
     def preprocessEvents(self, events: List[Event]):
-        if self.extendEvents is not None:
-            events = self.preprocessEventsByConfig(events, self.extendEvents)
+        events = self.preprocessEventsByConfig(events, self.eventConfig)
         return events
 
-    def preprocessEventsByConfig(self, events: List[Event], extendEventMap):
-        for event in events:
-            if event.name in extendEventMap:
-                addBefore, addAfter = extendEventMap[event.name]
-                event.start -= addBefore
-                event.duration += addBefore + addAfter
+    def preprocessEventsByConfig(self, events: List[Event], eventConfig):
+        extendEvents = eventConfig["extendEvents"]
+        if extendEvents is not None:
+            for event in events:
+                if event.name in extendEvents:
+                    addBefore, addAfter = extendEvents[event.name]
+                    event.start -= addBefore
+                    event.duration += addBefore + addAfter
         return events
 
     # def extractRecordAndAnnotations(self, recordName):
